# Copyright (c) Stas Shtin, 2010

# This file is part of IPyPBX.

# IPyPBX is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# IPyPBX is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with IPyPBX.  If not, see <http://www.gnu.org/licenses/>.

import os
import sys
from ipypbx import controllers, sql, ui
from PyQt4 import QtCore, QtGui, QtSql


# Working directory path.
# NOTE: ~/.ipypbx gives an error - for some reason QT doesn't like the dot?
PREFIX = os.path.expanduser('~/.ipypbx')

# Database file name.
DB_NAME = 'ipypbx.db'


def setupDb(prefix=PREFIX, dbname=DB_NAME):
    """
    Setup database.
    """
    created = False
    # Create it if necessary.
    if prefix:
        if not os.path.exists(prefix):
            created = True
            os.mkdir(prefix, 0700)
        
        os.chdir(prefix)
    
    # Connect to SQLite database.
    db = QtSql.QSqlDatabase.addDatabase("QSQLITE")
    db.setDatabaseName(dbname)
    
    if db.open():
        if created:
            for query in sql.creation_queries:
                QtSql.QSqlQuery().exec_(query)
    else:
        QtGui.QMessageBox.warning(
            None, "Fatal Error", "Database Error: %s" % db.lastError().text())
        sys.exit(1)

    
if __name__ == '__main__':
    app = QtGui.QApplication(sys.argv)
    setupDb()
    views = ui.MainWindow()
    views.show()

    connectionController = controllers.ConnectionController(parent=views)

    app.exec_()
#    sys.exit()
